<?php

/**
 * This is the model class for table "pc_agents".
 *
 * The followings are the available columns in table 'pc_agents':
 * @property integer $pcag_id
 * @property string $pcag_store_name
 * @property string $pcag_fname
 * @property string $pcag_lname
 * @property string $pcag_email
 * @property string $pcag_mobile_number
 * @property integer $pcag_status
 * @property string $pcag_created_at
 * @property string $pcag_updated_at
 */
class Agents extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'pc_agents';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('pcag_store_name, pcag_fname, pcag_lname,pcag_address, pcag_email, pcag_mobile_number,pcag_charges, pcag_status', 'required','on'=>'update,addAgents,updateAgents'),
			array('pcag_status', 'numerical', 'integerOnly'=>true,'on'=>'update,addAgents,updateAgents'),
			array('pcag_store_name, pcag_fname, pcag_lname, pcag_email, pcag_mobile_number', 'length', 'max'=>32,'on'=>'update,addAgents,updateAgents'),
			
			array('pcag_id, pcag_store_name, pcag_fname,pcag_address, pcag_lname, pcag_charges,pcag_email, pcag_mobile_number, pcag_status, pcag_created_at, pcag_updated_at', 'safe', 'on'=>'search,update,addAgents,updateAgents'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'pcag_id' => 'Pcag',
			'pcag_store_name' => 'Store Name',
			'pcag_fname' => 'First name',
			'pcag_lname' => 'Last name',
			'pcag_email' => 'Email',
			'pcag_address' => 'Store Address',
			'pcag_mobile_number' => 'Mobile Number',
			'pcag_charges' => 'Charges',
			'pcag_status' => 'Status',
			'pcag_created_at' => 'Created Date',
			'pcag_user_opensource' => 'Password',
			'pcag_updated_at' => 'Updated At',
		);
	}

	public static function listData()
	{
		$listData = CHtml::listData(Agents::model()->findAll(array('condition'=>'','order'=>'pcag_store_name ASC')),'pcag_id','pcag_store_name');
		return $listData;
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function admin_agent_search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('pcag_id',$this->pcag_id);
		$criteria->compare('pcag_store_name',$this->pcag_store_name,true);
		$criteria->compare('pcag_fname',$this->pcag_fname,true);
		$criteria->compare('pcag_lname',$this->pcag_lname,true);
		$criteria->compare('pcag_email',$this->pcag_email,true);
		$criteria->compare('pcag_charges',$this->pcag_charges,true);
		$criteria->compare('pcag_mobile_number',$this->pcag_mobile_number,true);
		$criteria->compare('pcag_status',$this->pcag_status);
		$criteria->compare('pcag_created_at',$this->pcag_created_at,true);
		$criteria->compare('pcag_updated_at',$this->pcag_updated_at,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
			 'sort'=>array(
                        'defaultOrder'=>'pcag_id DESC',
                    ),
		));
	}

	public function beforeSave(){
		if($this->isNewRecord)
			$this->pcag_created_at	= date('Y-m-d H:i:s');
		else
			$this->pcag_updated_at	= date('Y-m-d H:i:s');

		return true;
	}
	
	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Agents the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	
}
