<?php

/**
 * This is the model class for table "pc_invoice".
 *
 * The followings are the available columns in table 'pc_invoice':
 * @property integer $pci_id
 * @property string $pci_to
 * @property string $pci_from
 * @property string $pci_created_date
 * @property string $pci_invoice_no
 * @property string $pci_invoice_amt
 * @property integer $pci_status
 */
class Invoice extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'pc_invoice';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('pci_to, pci_from, pci_created_date, pci_invoice_no, pci_invoice_amt, pci_status', 'required'),
			array('pci_status', 'numerical', 'integerOnly'=>true),
			array('pci_to, pci_from', 'length', 'max'=>255),
			array('pci_created_date, pci_invoice_no, pci_invoice_amt', 'length', 'max'=>32),
			array('pci_id, pci_to, pci_from, pci_created_date, pci_invoice_no, pci_invoice_amt, pci_status', 'safe', 'on'=>'search,user_invoices_search,add'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'UserRel' => array(self::BELONGS_TO, 'Userdetails', 'pci_userid'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'pci_id' => 'Pci',
			'pci_to' => 'Bill To',
			'pci_from' => 'Pci From',
			'pci_created_date' => 'Invoice Date',
			'pci_invoice_no' => 'Invoice No',
			'pci_invoice_amt' => 'Amount',
			'pci_status' => 'Status',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function admin_invoices_search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;
		$criteria->with = array('UserRel');
		$criteria->together = true;
		$criteria->compare('pci_id',$this->pci_id);
		$criteria->compare('pci_to',$this->pci_to,true);
		$criteria->compare('pci_userid',$this->pci_userid,true);
		$criteria->compare('pci_from',$this->pci_from,true);
		$criteria->compare('pci_created_date',$this->pci_created_date,true);
		$criteria->compare('pci_invoice_no',$this->pci_invoice_no,true);
		$criteria->compare('pci_invoice_amt',$this->pci_invoice_amt,true);
		$criteria->compare('pci_status',$this->pci_status);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
			'sort'=>array(
                        'defaultOrder'=>'pci_id DESC',
                    ),
		));
	}

	public function user_invoices_search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('pci_id',$this->pci_id);
		$criteria->compare('pci_to',$this->pci_to,true);
		$criteria->compare('pci_userid',Yii::app()->user->getState('Userid'));
		$criteria->compare('pci_from',$this->pci_from,true);
		$criteria->compare('pci_created_date',$this->pci_created_date,true);
		$criteria->compare('pci_invoice_no',$this->pci_invoice_no,true);
		$criteria->compare('pci_invoice_amt',$this->pci_invoice_amt,true);
		$criteria->compare('pci_status',$this->pci_status);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
			'sort'=>array(
                        'defaultOrder'=>'pci_id DESC',
                    ),
		));
	}
	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return Invoice the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	public function getfullName(){

		return $this->pcu_firstname.' '.$this->pcu_lastname;
	}
}
