<?php

/**
 * This is the model class for table "pc_paysuh_carddata".
 *
 * The followings are the available columns in table 'pc_paysuh_carddata':
 * @property integer $id
 * @property integer $user_id
 * @property string $card_name
 * @property integer $card_method
 * @property string $card_type
 * @property string $card_number
 * @property string $cc_opensource
 * @property double $camount
 * @property string $authcode
 * @property string $trans_id
 * @property integer $created_date
 */
class PaysuhCarddata extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'pc_paysuh_carddata';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('id, user_id, card_name, card_type, card_number, cc_opensource, camount, authcode, trans_id, created_date', 'required'),
			array('id, user_id, card_method, created_date', 'numerical', 'integerOnly'=>true),
			array('camount', 'numerical'),
			array('card_name, card_number, cc_opensource', 'length', 'max'=>50),
			array('card_type', 'length', 'max'=>10),
			array('authcode', 'length', 'max'=>25),
			array('trans_id', 'length', 'max'=>100),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('id, user_id, card_name, card_method, card_type, card_number, cc_opensource, camount, authcode, trans_id, created_date', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id' => 'ID',
			'user_id' => 'User',
			'card_name' => 'Card Name',
			'card_method' => '0-credit,1-debit',
			'card_type' => 'Card Type',
			'card_number' => 'Card Number',
			'cc_opensource' => 'Cc Opensource',
			'camount' => 'Camount',
			'authcode' => 'Authcode',
			'trans_id' => 'Trans',
			'created_date' => 'Created Date',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id);
		$criteria->compare('user_id',$this->user_id);
		$criteria->compare('card_name',$this->card_name,true);
		$criteria->compare('card_method',$this->card_method);
		$criteria->compare('card_type',$this->card_type,true);
		$criteria->compare('card_number',$this->card_number,true);
		$criteria->compare('cc_opensource',$this->cc_opensource,true);
		$criteria->compare('camount',$this->camount);
		$criteria->compare('authcode',$this->authcode,true);
		$criteria->compare('trans_id',$this->trans_id,true);
		$criteria->compare('created_date',$this->created_date);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
			'sort'=>array(
                        'defaultOrder'=>'id DESC',
                    ),
		));
	}


	public function beforeSave(){
		
		$this->created_date	= date('Y-m-d H:i:s');

		return true;
	}
	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return PaysuhCarddata the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
