<?php

/**
 * This is the model class for table "pc_processing_fee".
 *
 * The followings are the available columns in table 'pc_processing_fee':
 * @property integer $pcpf_id
 * @property string $pcpf_name
 * @property double $pcpf_value
 * @property double $pcpf_percentage
 * @property integer $pcpf_status
 */
class ProcessingFee extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'pc_processing_fee';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('pcpf_name', 'unique'),
			array('pcpf_name', 'required'),
			array('pcpf_value, pcpf_percentage', 'numerical'),
			array('pcpf_name', 'length', 'max'=>32),
			array('pcpf_id, pcpf_name, pcpf_value, pcpf_percentage, pcpf_status', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'pcpf_id' => 'Pcpf',
			'pcpf_name' => 'Name',
			'pcpf_value' => 'Value (JMD)',
			'pcpf_percentage' => 'Percentage (%)',
			'pcpf_status' => 'Status',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('pcpf_id',$this->pcpf_id);
		$criteria->compare('pcpf_name',$this->pcpf_name,true);
		$criteria->compare('pcpf_value',$this->pcpf_value);
		$criteria->compare('pcpf_percentage',$this->pcpf_percentage);
		$criteria->compare('pcpf_status',$this->pcpf_status);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
			'sort'=>array(
                        'defaultOrder'=>'pcpf_id DESC',
                    ),
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return ProcessingFee the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
