<?php

/**
 * This is the model class for table "pc_user".
 *
 * The followings are the available columns in table 'pc_user':
 * @property integer $user_id
 * @property string $user_email
 * @property string $user_password
 * @property string $user_opensource
 * @property string $user_lastlogin
 * @property string $user_ipaddress
 * @property integer $user_type
 * @property integer $user_userid
 * @property integer $user_status
 * @property string $user_activecode
 * @property integer $user_activestatus
 * @property string $user_activedate
 */
class User extends CActiveRecord
{

	public $user_password;
	public $user_password_repeat;
	public $old_password;
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'pc_user';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			
			array('user_password', 'required', 'on'=>'PasswordUpdate,resetpass'),
			array('user_temp_key', 'required', 'on'=>'resetpass'),
			array('user_password', 'passwordStrength', 'on'=>'resetpass'),
			array('user_temp_key', 'tempKeyValidate', 'on'=>'resetpass'),
			array('user_password', 'compare','on'=>'PasswordUpdate,resetpass'),
			array('user_password_repeat', 'safe'),
			
			array('user_id, user_email, user_password, user_opensource, user_lastlogin, user_ipaddress, user_type, user_userid, user_status, user_activecode, user_activestatus,user_salt, user_activedate,user_temp_key', 'safe', 'on'=>'search,PasswordUpdate,resetpass'),
		);
	}
	
	
	public function tempKeyValidate($attribute)
	{
		$checkSec_cde = User::model()->findByAttributes(array('user_temp_key'=>$this->user_temp_key, 'user_activecode'=>0));
		
		if($checkSec_cde == ''){		
			$this->addError('user_temp_key', 'Please provide the security code from your email.');
		} 
	}
	
	public function passwordStrength($attribute)
	{
	    $pattern = '/^(?=.*\d(?=.*\d))(?=.*[a-zA-Z](?=.*[a-zA-Z])).{5,}$/';  
	 
	    if(!preg_match($pattern, $this->$attribute))
	      $this->addError($attribute, 'For security reasons, we recommended using alphanumerical characters or symbols in your password.');
	}	
	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'user_id' => 'User',
			'user_email' => 'User Email',
			'user_password' => 'Password',
			'user_password_repeat' => 'Repeat Password',
			'user_opensource' => 'User Opensource',
			'user_lastlogin' => 'User Lastlogin',
			'user_ipaddress' => 'User Ipaddress',
			'user_type' => '1-Admin, 2 - User',
			'user_userid' => 'User Userid',
			'user_status' => '0-Inactive, 1-Active, 2-Pending',
			'user_activecode' => 'User Activecode',
			'user_activestatus' => '0-Not Verified, 1-Verified',
			'user_temp_key' => 'Security Code',
			'user_activedate' => 'User Activedate',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('user_id',$this->user_id);
		$criteria->compare('user_email',$this->user_email,true);
		$criteria->compare('user_password',$this->user_password,true);
		$criteria->compare('user_opensource',$this->user_opensource,true);
		$criteria->compare('user_lastlogin',$this->user_lastlogin,true);
		$criteria->compare('user_ipaddress',$this->user_ipaddress,true);
		$criteria->compare('user_type',$this->user_type);
		$criteria->compare('user_userid',$this->user_userid);
		$criteria->compare('user_status',$this->user_status);
		$criteria->compare('user_activecode',$this->user_activecode,true);
		$criteria->compare('user_activestatus',$this->user_activestatus);
		$criteria->compare('user_activedate',$this->user_activedate,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return User the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
